<?php
// This file is part of the Studyplan plugin for Moodle
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.
/**
 * Entry point for external people to access a studyplan view with an invitation
 * @package    local_treestudyplan
 * @copyright  2023 P.M. Kuipers
 * @license    https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once("../../config.php");
// Since this page is externally accessed and validated in a different way, no login is needed.

/**
 * Shortcut function to provide translations
 *
 * @param mixed $str Translation key
 * @param null|string[] $param Parameters to pass to translation
 * @param string $plugin Location to search for translation strings
 * @return string Translation of key
 */
function t($str, $param = null, $plugin = 'local_treestudyplan') {
    print get_string($str, $plugin, $param);
}

$systemcontext = context_system::instance();
$PAGE->set_pagelayout('base');
$PAGE->set_context($systemcontext);

// See if we can get a valid user for this invited.
$invitekey = optional_param('key', '', PARAM_ALPHANUM);     // Module name.
$PAGE->set_url("/local/treestudyplan/invited.php", array('key' => $invitekey));

$invite = $DB->get_record_select("local_treestudyplan_invit",
                                 $DB->sql_compare_text("invitekey"). " = " . $DB->sql_compare_text(":invitekey"),
                                 ['invitekey' => $invitekey]);

if (empty($invite)) {
    $PAGE->set_title(get_string('invalid_invitekey_title', 'local_treestudyplan'));
    $PAGE->set_heading(get_string('invalid_invitekey_title', 'local_treestudyplan'));

    print $OUTPUT->header();

    // Render page for skill level 0 (global).

    print "<div class='box errorbox alert alert-danger'>";
    print get_string('invalid_invitekey_error', 'local_treestudyplan');
    print "</div>";

    print $OUTPUT->footer();

    exit;
} else {
    // Load javascripts and specific css.
    $PAGE->requires->css(new moodle_url($CFG->wwwroot.'/local/treestudyplan/css/bootstrap-vue/bootstrap-vue.css'));
    $PAGE->requires->css(new moodle_url($CFG->wwwroot.'/local/treestudyplan/css/devstyles.css'));
    $PAGE->requires->js_call_amd('local_treestudyplan/page-myreport', 'init', ['invited', $invitekey]);

    $student = $DB->get_record('user', array('id' => $invite->user_id));
    $PAGE->set_title(get_string('report_invited', 'local_treestudyplan', "{$student->firstname} {$student->lastname}" ));
    $PAGE->set_heading(get_string('report_invited', 'local_treestudyplan', "{$student->firstname} {$student->lastname}"));

    print $OUTPUT->header();
    ?>
    <div id='root'>
        <div class='vue-loader' v-show='false'>
            <div class="spinner-border text-primary" role="status">
                <span class="sr-only">Loading...</span>
            </div>
        </div>
        <div v-cloak>
            <r-report v-model="studyplans" :guestmode="true"></r-report>
        </div>
    </div>

    <?php

    print $OUTPUT->footer();
}
